Operationalisation Van den Hoogen et al. 2023

* Stata version
version 17

****PLEASE READ******
*THE DATA FOR THE PREMEASURES ARE AVAILABLE VIA THIS LINK: https://www.dataarchive.lissdata.nl/study_units/view/1402 
*THE DATA FOR THE SURVEY EXPERIMENT ARE AVAILABLE VIA THIS LINK: https://www.dataarchive.lissdata.nl/study_units/view/1418 
****PLEASE READ*****

* MAKE SURE THAT THE DIRECTORY IN WHICH THE DATA ARE STORED IS THE CURRENT DIRECTORY

********************************************************************************
*********************Import data + opening log *********************************
********************************************************************************

* Use  data 
use "Replication data Van den Hoogen et al -- REVISION -- EU policy.dta", replace

*Opening log
log using "OPERATIONALISATION EU policy experiment - revision.smcl", replace

********************************************************************************
***********************  Preparation premeasures  ******************************
********************************************************************************

*EU attitudes from premeasure survey, and change names into English (+ make clear they are premeasures)
*Check pu20a188 - Dutch membership of the European Union is a good thing.
tab pu20a188, m
*Recode: pu20a188 becomes PreNegviewEU
recode pu20a188 (1=7) (2=6) (3=5) (4=4) (5=3) (6=2) (7=1), generate(PreNegviewEU)
label variable PreNegviewEU "Negative view on EU membership" 
tab PreNegviewEU, missing
*check recode
tab PreNegviewEU pu20a188, m

*Check pu20a194 - The European Union should be enlarged with other countries.
tab pu20a194, m
*pu20a194 becomes PreNegviewEnl
recode pu20a194 (1=7) (2=6) (3=5) (4=4) (5=3) (6=2) (7=1), generate(PreNegviewEnl)
label variable PreNegviewEnl "Negative view on EU enlargment" 
tab PreNegviewEnl, missing
*check recode
tab PreNegviewEnl pu20a194, m

*pu20a191 - The Netherlands should leave the European Union.
tab pu20a191, m
*Change varname
clonevar PreNexit = pu20a191
label variable PreNexit "Premeasure Nexit"
*Check
tab PreNexit, m

*pu20a201 - The European Union endangers the independence of the Netherlands.
tab pu20a201, m
*Change varname
clonevar PreIndep = pu20a201
label variable PreIndep "Premeasure independence"
*Check
tab PreIndep, m

*pu20a190 - I am disgusted by the European Union.
tab pu20a190, m
*Change varname
clonevar PreDisgust = pu20a190
label variable PreDisgust "Premeasure disgust EU"
*Check
tab PreDisgust, m

********************************************************************************
*******************  Preparation dependent variables  **************************
********************************************************************************

*uz22a010 - Dutch membership of the European Union is a good thing.
tab uz22a010, m
*uz22a010 becomes NegViewEU
recode uz22a010 (1=7) (2=6) (3=5) (4=4) (5=3) (6=2) (7=1), generate(NegViewEU)
label variable NegViewEU "Negative view on EU membership" 
tab NegViewEU, missing
*check recode
tab NegViewEU uz22a010, m

*uz22a011 - The European Union should be enlarged with other countries.
tab uz22a011, m
*uz22a011 becomes NegViewEnl
recode uz22a011 (1=7) (2=6) (3=5) (4=4) (5=3) (6=2) (7=1), generate(NegViewEnl)
label variable NegViewEnl "Negative view on EU enlargment" 
tab NegViewEnl, missing
*check recode
tab NegViewEnl uz22a011, m

*uz22a012 - The Netherlands should leave the European Union.
tab uz22a012, m
*Change varname
clonevar Nexit = uz22a012
label variable Nexit "Attitude towards Nexit"
*Check
tab Nexit, m

*uz22a013 - The European Union endangers the independence of the Netherlands.
tab uz22a013, m
*Change varname
clonevar Indep = uz22a013
label variable Indep "EU Endangers independence"
*Check
tab Indep, m

*uz22a014 - I am disgusted by the European Union.
tab uz22a014, m 
*Change varname
clonevar Disgust = uz22a014
label variable Disgust "EU disgust"
*Check
tab Disgust, m

********************************************************************************
*****************    Preparation independent variables *************************
********************************************************************************

*Make dummy variable of the experimental condition to which respondents are exposed (no information on proposal/information on proposal)
recode uz22a009 (1 3=0) (2 4=1), generate(AbolishVeto)
label variable AbolishVeto "Received proposal to abolish veto"
label define AbolishVetolabel 0 "No proposal for abolishment veto" 1 "Proposal for abolishment veto"
label values AbolishVeto AbolishVetolabel
tab AbolishVeto, missing
*check recode
tab AbolishVeto uz22a009, m 

*Make dummy variable of the experimental condition to which respondents are exposed (Non-Eurosceptic medium / Eurosceptic medium) 
recode uz22a009 (3 4=0) (1 2=1), generate(EuroscepticMedium)
label variable EuroscepticMedium "Received Eurosceptic medium"
label define EuroscepticMediumlabel 0 "Non-Eurosceptic medium" 1 "Eurosceptic medium"
label values EuroscepticMedium EuroscepticMediumlabel
tab EuroscepticMedium, missing
*check recode
tab EuroscepticMedium uz22a009, m 

********************************************************************************
*******************    Preparation moderating variables  ***********************
********************************************************************************

*Populist attitudes
*Check variables
*pu20a065 - The people, and not politicians, should make our most important policy decisions.
tab pu20a065, m
*pu20a066 - The political differences between the elite* and the people are larger than the differences among the people.
tab pu20a066, m
*pu20a067 - I would rather be represented by a citizen than by a specialized politician.
tab pu20a067, m
*pu20a068 - Elected officials talk too much and take too little action.
tab pu20a068, m
*pu20a069 - What people call "compromise" in politics is really just selling out on one's principles.
tab pu20a069, m

*factor analysis
factor pu20a065 pu20a066 pu20a067 pu20a068 pu20a069, pcf
*Eigenvalue of 2.99, items explain 60% of the variance
alpha pu20a065 pu20a066 pu20a067 pu20a068 pu20a069
*alpha is 0.83
*generate variable (sum)
egen prepopatt = rowmean(pu20a065 pu20a066 pu20a067 pu20a068 pu20a069)
label variable prepopatt "Premeasure Populist attitudes"
tab prepopatt, m
summarize prepopatt 

*nationalism
*Check variables
tab pu20a062, m
tab pu20a063, m

alpha pu20a062 pu20a063, std
*alpha is 0.64

egen natatt = rowmean(pu20a062 pu20a063)
label variable natatt "nationalism"
tab natatt, m
summarize natatt

* Save replication data under new name
save "Operationalised replication data Van den Hoogen et al -- REVISION -- EU policy.dta", replace

log close

exit
