Main analysis Van den Hoogen et al. 2023

* Stata version
version 17

* MAKE SURE THAT THE DIRECTORY IN WHICH THE DATA ARE STORED IS THE CURRENT DIRECTORY

********************************************************************************
*********************Import data + opening log **********************************
********************************************************************************

* Use  data 
use "Operationalised replication data Van den Hoogen et al -- REVISION -- EU policy.dta", replace

*Opening log
log using "MAIN ANALYSIS EU policy experiment - REVISION.smcl", replace

********************************************************************************
**************************  Main analysis  *************************************
********************************************************************************
*OLS regression analyses 

*Model 1 (main effect)
*Model 1: negative view on EU membership 
regress NegViewEU AbolishVeto PreNegviewEU

*Model 1: negative view on EU enlargement
regress NegViewEnl AbolishVeto PreNegviewEnl

*Model 1: support of a nexit 
regress Nexit AbolishVeto PreNexit

*Model 1: Belief dat the EU endangers Dutch sovereignty 
regress Indep AbolishVeto PreIndep

*Model 1: Disgust with the EU 
regress Disgust AbolishVeto PreDisgust

*Model 2 (moderation effect populist attitudes)
*Model 2: negative view on EU membership
regress NegViewEU PreNegviewEU i.AbolishVeto##c.prepopatt
margins, dydx(AbolishVeto) at(prepopatt=(1/7))
marginsplot, yline(0) graphregion(color(white)) title ("Negative view on EU membership", size(small)) recast(line) recastci(rarea) ci1opt(fcolor(none) lcolor(black) lpattern(dash)) ytitle(" ") legend(off) addplot(histogram prepopatt, percent yscale(r(-1 0.8) axis(1)) ylabel(0(2)12, axis(2)) ylabel(-1(0.2)0.8) xtitle(" ") xlabel(1(1)7, labsize(small)) yaxis(2) ytitle(" ", axis(2)) ysc(axis(2) alt) fcolor(gs14%40) lcolor(gs14%40))
graph save EUPOL-m2a.gph, replace
graph export EUPOL-m2a.png, replace

*Model 2: negative view on EU enlargement
regress NegViewEnl PreNegviewEnl i.AbolishVeto##c.prepopatt
margins, dydx(AbolishVeto) at(prepopatt=(1/7))
marginsplot, yline(0) graphregion(color(white)) title ("Negative view on EU enlargement", size(small)) recast(line) recastci(rarea) ci1opt(fcolor(none) lcolor(black) lpattern(dash)) ytitle(" ") legend(off) addplot(histogram prepopatt, percent yscale(r(-1 0.8) axis(1)) ylabel(0(2)12, axis(2)) ylabel(-1(0.2)0.8) xtitle(" ") xlabel(1(1)7, labsize(small)) yaxis(2) ytitle(" ", axis(2)) ysc(axis(2) alt) fcolor(gs14%40) lcolor(gs14%40))
graph save EUPOL-m2b.gph, replace
graph export EUPOL-m2b.png, replace

*Model 2: support of a nexit
regress Nexit PreNexit i.AbolishVeto##c.prepopatt
margins, dydx(AbolishVeto) at(prepopatt=(1/7))
marginsplot, yline(0) graphregion(color(white)) title ("Support for a Nexit", size(small)) recast(line) recastci(rarea) ci1opt(fcolor(none) lcolor(black) lpattern(dash)) ytitle(" ") legend(off) addplot(histogram prepopatt, percent yscale(r(-1 0.8) axis(1)) ylabel(0(2)12, axis(2)) ylabel(-1(0.2)0.8) xtitle(" ") xlabel(1(1)7, labsize(small)) yaxis(2) ytitle(" ", axis(2)) ysc(axis(2) alt) fcolor(gs14%40) lcolor(gs14%40))
graph save EUPOL-m2c.gph, replace
graph export EUPOL-m2c.png, replace

*Model 2: Belief that the EU endangers Dutch sovereignty
regress Indep PreIndep i.AbolishVeto##c.prepopatt
margins, dydx(AbolishVeto) at(prepopatt=(1/7))
marginsplot, yline(0) graphregion(color(white)) title ("Belief that the EU endangers Dutch sovereignty", size(small)) recast(line) recastci(rarea) ci1opt(fcolor(none) lcolor(black) lpattern(dash)) ytitle(" ") legend(off) addplot(histogram prepopatt, percent yscale(r(-1 0.8) axis(1)) ylabel(0(2)12, axis(2)) ylabel(-1(0.2)0.8) xtitle(" ") xlabel(1(1)7, labsize(small)) yaxis(2) ytitle(" ", axis(2)) ysc(axis(2) alt) fcolor(gs14%40) lcolor(gs14%40))
graph save EUPOL-m2d.gph, replace
graph export EUPOL-m2d.png, replace

*Model 2: Disgust with the EU
regress Disgust PreDisgust i.AbolishVeto##c.prepopatt
margins, dydx(AbolishVeto) at(prepopatt=(1/7))
marginsplot, yline(0) graphregion(color(white)) title ("Disgust with the EU", size(small)) recast(line) recastci(rarea) ci1opt(fcolor(none) lcolor(black) lpattern(dash)) ytitle(" ") legend(off) addplot(histogram prepopatt, percent yscale(r(-1 0.8) axis(1)) ylabel(0(2)12, axis(2)) ylabel(-1(0.2)0.8) xtitle(" ") xlabel(1(1)7, labsize(small)) yaxis(2) ytitle(" ", axis(2)) ysc(axis(2) alt) fcolor(gs14%40) lcolor(gs14%40))
graph save EUPOL-m2e.gph, replace
graph export EUPOL-m2e.png, replace

graph combine EUPOL-m2a.gph EUPOL-m2b.gph EUPOL-m2c.gph EUPOL-m2d.gph EUPOL-m2e.gph, graphregion(color(white)) b1title("Populist attitudes", size(small)) l1title("Marginal effect of information on linear prediction", size(small)) r1title("Distribution of respondents (in %)", size(small))
graph save EUPOL--FIGURE1-combined.gph, replace
graph export EUPOL--FIGURE1-combined.pdf, replace
graph export EUPOL--FIGURE1-combined.png, replace

*Model 3 (moderation effect populist attitudes, on Eurosceptic/ non-Eurosceptic medium)
*Model 3: negative view on EU membership
regress NegViewEU PreNegviewEU i.AbolishVeto##i.EuroscepticMedium
margins AbolishVeto#EuroscepticMedium
marginsplot, recast(scatter) graphregion(color(white)) plotregion(margin(xsmall)) title("Negative view on EU membership", size(small) color(gs0)) ytitle ("") xtitle ("") xscale(r(-1 2)) xlabel (0 "No proposal" 1 "Proposal", labsize(small)) ylabel(2.2(.2)4, labsize(small))
graph save EUPOL-m3a.gph, replace
graph export EUPOL-m3a.png, replace

*Model 3: negative view on EU enlargement
regress NegViewEnl PreNegviewEnl i.AbolishVeto##i.EuroscepticMedium
margins AbolishVeto#EuroscepticMedium
marginsplot, recast(scatter) graphregion(color(white)) plotregion(margin(xsmall)) title("Negative view on EU enlargement", size(small) color(gs0)) ytitle ("") xtitle ("") xscale(r(-1 2)) xlabel (0 "No proposal" 1 "Proposal", labsize(small)) ylabel(2.2(.2)4, labsize(small))
graph save EUPOL-m3b.gph, replace
graph export EUPOL-m3b.png, replace

*Model 3: support of a nexit
regress Nexit PreNexit i.AbolishVeto##i.EuroscepticMedium
margins AbolishVeto#EuroscepticMedium
marginsplot, recast(scatter) graphregion(color(white)) plotregion(margin(xsmall)) title("Support for a Nexit", size(small) color(gs0)) ytitle ("") xtitle ("") xscale(r(-1 2)) xlabel (0 "No proposal" 1 "Proposal", labsize(small)) ylabel(2.2(.2)4, labsize(small))
graph save EUPOL-m3c.gph, replace
graph export EUPOL-m3c.png, replace

*Model 3: Belief that the EU endangers Dutch sovereignty
regress Indep PreIndep i.AbolishVeto##i.EuroscepticMedium
margins AbolishVeto#EuroscepticMedium
marginsplot, recast(scatter) graphregion(color(white)) plotregion(margin(xsmall)) title("Belief that the EU endangers Dutch sovereignty", size(small) color(gs0)) ytitle ("") xtitle ("") xscale(r(-1 2)) xlabel (0 "No proposal" 1 "Proposal", labsize(small)) ylabel(2.2(.2)4, labsize(small))
graph save EUPOL-m3d.gph, replace
graph export EUPOL-m3d.png, replace

*Model 3: Disgust with the EU
regress Disgust PreDisgust i.AbolishVeto##i.EuroscepticMedium
margins AbolishVeto#EuroscepticMedium
marginsplot, recast(scatter) graphregion(color(white)) plotregion(margin(xsmall)) title("Disgust with the EU", size(small) color(gs0)) ytitle ("") xtitle ("") xscale(r(-1 2)) xlabel (0 "No proposal" 1 "Proposal", labsize(small)) ylabel(2.2(.2)4, labsize(small))
graph save EUPOL-m3e.gph, replace
graph export EUPOL-m3e.png, replace  

grc1leg EUPOL-m3a.gph EUPOL-m3b.gph EUPOL-m3c.gph EUPOL-m3d.gph EUPOL-m3e.gph, legendfrom(EUPOL-m3e.gph) graphregion(color(white))
graph save EUPOL--FIGURE2-combined.gph, replace
graph export EUPOL--FIGURE2-combined.png, replace
graph export EUPOL--FIGURE2-combined.pdf, replace

*Save replication data under new name
save "MAIN ANALYSIS replication data Van den Hoogen et al -- REVISION -- EU policy.dta", replace

log close

exit
