Exploratory analyses Van den Hoogen et al. 2023

* Stata version
version 17

* MAKE SURE THAT THE DIRECTORY IN WHICH THE DATA ARE STORED IS THE CURRENT DIRECTORY

********************************************************************************
*********************Import data + opening log **********************************
********************************************************************************

* Use  data 
use "Operationalised replication data Van den Hoogen et al -- REVISION -- EU policy.dta", replace

*Opening log
log using "EXPLORATORY ANALYSES EU policy experiment - REVISION.smcl", replace

********************************************************************************
***********************  Exploratory analyses **********************************
********************************************************************************

***********************  Exploratory analysis 1 ********************************

*Direct effect van het medium
*Negative view on EU membership 
regress NegViewEU EuroscepticMedium PreNegviewEU

*Negative view on EU enlargement
regress NegViewEnl EuroscepticMedium PreNegviewEnl

*Support of a nexit 
regress Nexit EuroscepticMedium PreNexit

*Belief dat the EU endangers Dutch sovereignty 
regress Indep EuroscepticMedium PreIndep

*Disgust with the EU 
regress Disgust EuroscepticMedium PreDisgust

***********************  Exploratory analysis 2 ********************************

*Extra measurements on credibility and comprehensibility of the treatments
tab uz22a017, m
tab uz22a018, m

*Check if there are differences between treatments in credibility and comprehensibility
oneway uz22a009 uz22a017
oneway uz22a009 uz22a018

***********************  Exploratory analysis 3 ********************************

*Check if populist attitudes is associated with more/ less credibility and comprehensibility
pwcorr uz22a017 prepopatt, sig
pwcorr uz22a018 prepopatt, sig


***********************  Exploratory analysis 4 ********************************
*Check if variable "nationalism" moderates

*Model 2: negative view on EU membership
regress NegViewEU PreNegviewEU i.AbolishVeto##c.natatt

*Model 2: negative view on EU enlargement
regress NegViewEnl PreNegviewEnl i.AbolishVeto##c.natatt

*Model 2: support of a nexit
regress Nexit PreNexit i.AbolishVeto##c.natatt

*Model 2: Belief dat the EU endangers Dutch sovereignty
regress Indep PreIndep i.AbolishVeto##c.natatt

*Model 2: Disgust with the EU
regress Disgust PreDisgust i.AbolishVeto##c.natatt


********************************************************************************
*************************  Manipulation check **********************************
********************************************************************************


*Manipulation check message
tab uz22a015, mis
recode uz22a015 (1 2 4 999=0) (3=1) (.=.), generate(Manicheck1COR)
label define correctmanicheck1 0 "Incorrect manicheck message" 1 "Correct manicheck message"
label values Manicheck1COR correctmanicheck1
tab Manicheck1COR, mis
*122 respondents incorrectly identified the correct texual element (don't knows and incorrect answers combined)

*Manipulation check medium
tab uz22a016, mis
tab EuroscepticMedium, mis

recode uz22a016 (1=1) (2 3 4 999=0) (.=.) if EuroscepticMedium==1, generate(Manicheck2ESM)
recode uz22a016 (2=1) (1 3 4 999=0) (.=.) if EuroscepticMedium==0, generate(Manicheck2NESM)
generate Manicheck2COR=0
recode Manicheck2COR (0=1) if Manicheck2ESM==1
recode Manicheck2COR (0=1) if Manicheck2NESM==1
recode Manicheck2COR (0=.) if uz22a016==.
label define correctmanicheck2 0 "Incorrect manicheck medium" 1 "Correct manicheck medium"
label values Manicheck2COR correctmanicheck2
tab Manicheck2COR, m
*788 respondents incorrectly identified the medium they were exposed to


*OLS regression analyses excluding respondents who failed manipulation check

*Model 1 (main effect)
*Model 1: negative view on EU membership 
regress NegViewEU AbolishVeto PreNegviewEU if Manicheck1COR==1 

*Model 1: negative view on EU enlargement
regress NegViewEnl AbolishVeto PreNegviewEnl if Manicheck1COR==1 

*Model 1: support of a nexit 
regress Nexit AbolishVeto PreNexit if Manicheck1COR==1  

*Model 1: Belief dat the EU endangers Dutch sovereignty 
regress Indep AbolishVeto PreIndep if Manicheck1COR==1 

*Model 1: Disgust with the EU 
regress Disgust AbolishVeto PreDisgust if Manicheck1COR==1 

*Model 2 (moderation effect populist attitudes)
*Model 2: negative view on EU membership
regress NegViewEU PreNegviewEU i.AbolishVeto##c.prepopatt if Manicheck1COR==1  

*Model 2: negative view on EU enlargement
regress NegViewEnl PreNegviewEnl i.AbolishVeto##c.prepopatt if Manicheck1COR==1   

*Model 2: support of a nexit
regress Nexit PreNexit i.AbolishVeto##c.prepopatt if Manicheck1COR==1  

*Model 2: Belief dat the EU endangers Dutch sovereignty
regress Indep PreIndep i.AbolishVeto##c.prepopatt if Manicheck1COR==1   
 
*Model 2: Disgust with the EU
regress Disgust PreDisgust i.AbolishVeto##c.prepopatt if Manicheck1COR==1 

*Model 3 (moderation effect populist attitudes, on Eurosceptic/ non-Eurosceptic medium)
*Model 3: negative view on EU membership
regress NegViewEU PreNegviewEU i.AbolishVeto##i.EuroscepticMedium if Manicheck2COR==1

*Model 3: negative view on EU enlargement
regress NegViewEnl PreNegviewEnl i.AbolishVeto##i.EuroscepticMedium if Manicheck2COR==1

*Model 3: support of a nexit
regress Nexit PreNexit i.AbolishVeto##i.EuroscepticMedium if Manicheck2COR==1

*Model 3: Belief dat the EU endangers Dutch sovereignty
regress Indep PreIndep i.AbolishVeto##i.EuroscepticMedium if Manicheck2COR==1

*Model 3: Disgust with the EU
regress Disgust PreDisgust i.AbolishVeto##i.EuroscepticMedium if Manicheck2COR==1


*Save replication data under new name
save "EXPLORATORY ANALYSES replication data Van den Hoogen et al -- EU policy.dta", replace

log close

exit

